summaryrefslogtreecommitdiff
path: root/src/theory/strings/base_solver.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/strings/base_solver.h')
-rw-r--r--src/theory/strings/base_solver.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/theory/strings/base_solver.h b/src/theory/strings/base_solver.h
index bf61b93b2..96d275cd5 100644
--- a/src/theory/strings/base_solver.h
+++ b/src/theory/strings/base_solver.h
@@ -106,7 +106,7 @@ class BaseSolver : protected EnvObj
/**
* Get the set of equivalence classes of type string.
*/
- const std::vector<Node>& getStringEqc() const;
+ const std::vector<Node>& getStringLikeEqc() const;
//-----------------------end query functions
private:
@@ -236,8 +236,8 @@ class BaseSolver : protected EnvObj
* for more information.
*/
std::map<Node, BaseEqcInfo> d_eqcInfo;
- /** The list of equivalence classes of type string */
- std::vector<Node> d_stringsEqc;
+ /** The list of equivalence classes of string-like types */
+ std::vector<Node> d_stringLikeEqc;
/** A term index for each type, function kind pair */
std::map<TypeNode, std::map<Kind, TermIndex> > d_termIndex;
/** the cardinality of the alphabet */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback